@@ -1,14 +1,54 @@
 
-#' Prediction for object class coco
-#' @description Prediction for a fitted coco object.
+#' Prediction routines for nonstationary spatial models
+#' @description Computes the point predictions and standard errors based on conditional Gaussian distributions.
 #' @usage cocoPredict(coco.object, newdataset, newlocs, type = 'mean', ...)
-#' @param coco.object a fitted coco object
-#' @param newdataset a data.frame including covariates present in model.list at prediction locations
-#' @param newlocs a matrix with locations related to prediction locations, matching indexing of newdataset
-#' @param type whether "mean" or "pred", which gives a point prediction for the former, as well as a combination of point prediction as well as prediction uncertainty for the latter
-#' @param ... when coco.object has multiple realizations, specifying 'index.pred' specifying which column of coco.object\@z should be used to perform predictions
-#' @returns a list with trend, and mean predictions and uncertainty quantification, if 'pred' is specified.
+#' @param coco.object (\code{S4}) a fitted \link{coco} object.
+#' @param newdataset (\code{data.frame}) a data.frame containing covariates present in model.list at prediction locations.
+#' @param newlocs (\code{matrix}) a matrix with locations related to prediction locations, matching indexing of \code{newdataset}.
+#' @param type (\code{character}) whether \code{"mean"} or \code{"pred"}, which gives a point prediction for the former, 
+#' as well as of point prediction and standard errors for the latter.
+#' @param ... (\code{character}) when coco.object has multiple realizations, specifying \code{"index.pred"} specifying which column of 
+#' \code{coco.object@z} should be used to perform predictions.
+#' @returns (\code{list}) a list with the conditional mean, splitted into the systematic large-scale variability \code{trend}, 
+#' and due to stochastic \code{mean}, as well as standard errors \code{"sd.pred"} if \code{"pred"} is specified.
 #' @author Federico Blasi
+#' @examples
+#' \dontrun{
+#'  
+#' model.list <- list('mean' = 0,
+#' 'std.dev' = formula( ~ 1 + cov_x + cov_y),
+#' 'scale' = formula( ~ 1 + cov_x + cov_y),
+#' 'aniso' = 0,
+#' 'tilt' = 0,
+#' 'smooth' = 3/2,
+#' 'nugget' = -Inf)
+#' 
+#' coco_object <- coco(type = 'dense',
+#' data = holes[[1]][1:100, ],
+#' locs = as.matrix(holes[[1]][1:100, 1:2]),
+#' z = holes[[1]][1:100, ]$z,
+#' model.list = model.list)
+#' 
+#' optim_coco <- cocoOptim(coco_object,
+#' boundaries = getBoundaries(coco_object,
+#' lower.value = -3, 3))
+#' 
+#' coco_preds <- cocoPredict(optim_coco, newdataset = holes[[2]],
+#' newlocs = as.matrix(holes[[2]][, 1:2]),
+#' type = "pred")
+#' 
+#' coco_preds
+#' 
+#' par(mfrow = c(1, 2))
+#' 
+#' fields::quilt.plot(main = "mean", holes[[2]][, 1:2], 
+#' coco_preds$mean, xlim = c(-1, 1), ylim = c(-1, 1))
+#' fields::quilt.plot(main = "se", holes[[2]][, 1:2], 
+#' coco_preds$sd.pred, xlim = c(-1, 1), ylim = c(-1, 1))
+#' 
+#' # Re-do it without considering cov_x and cov_y in the std.dev and scale and compare. 
+#' 
+#' }
 #' 
 cocoPredict <- function(coco.object, 
                         newdataset,
@@ -16,16 +56,12 @@ cocoPredict <- function(coco.object,
                         type = "mean",
                         ...) {
   
-  if (!('coco' %in% class(coco.object))){
-    stop("coco class required.")
-  }
-  
+  .cocons.check.coco(coco.object)
+
   if (length(coco.object@output) == 0) {
-    stop("object has not yet been fitted.")
+    stop("coco object has not yet been fitted.")
   }
   
-  
-  
   if(dim(coco.object@z)[2] == 1){
     index.pred <- 1
   } else{
@@ -39,11 +75,10 @@ cocoPredict <- function(coco.object,
       }
   }
   
-  .cocons.check.newdataset(newdataset)
+  .cocons.check.newdataset(newdataset, coco.object)
   .cocons.check.newlocs(newlocs)
   .cocons.check.type_pred(type)
-  .cocons.check.object(coco.object)
-    
+
   # add check on the names of newdataset names and model.list
   # add check type
   
@@ -73,7 +108,7 @@ cocoPredict <- function(coco.object,
     observed_cov <- cocons::cov_rns(
       theta = adjusted_eff_values[-1], locs = coco.object@locs,
       x_covariates = X_std$std.covs,
-      smooth_limits = coco.object@info$smooth_limits
+      smooth_limits = coco.object@info$smooth.limits
     )
     
     cov_pred <- cocons::cov_rns_pred(
@@ -81,7 +116,7 @@ cocoPredict <- function(coco.object,
       locs_pred = as.matrix(newlocs),
       x_covariates = X_std$std.covs,
       x_covariates_pred = X_pred_std$std.covs,
-      smooth_limits = coco.object@info$smooth_limits
+      smooth_limits = coco.object@info$smooth.limits
     )
     
     inv_cov <- solve(observed_cov, t(cov_pred))
@@ -90,9 +125,9 @@ cocoPredict <- function(coco.object,
     trend_pred <- c(X_pred_std$std.covs %*% adjusted_eff_values$mean)
     trendObs <- c(X_std$std.covs %*% adjusted_eff_values$mean)
     
-    coco.resid <- coco.object@z[,index.pred] - trendObs # Future updates add slice to pick from the samples
+    coco.resid <- coco.object@z[,index.pred] - trendObs
     
-    # mean part
+    # spatial mean
     mean_part <- c(crossprod(coco.resid, inv_cov))
     
     if (type == "mean") {
@@ -159,13 +194,13 @@ cocoPredict <- function(coco.object,
     taper_two <- coco.object@info$taper(distmat, theta = c(coco.object@info$delta, 1))
     
     # C(locs,locs)
-    taper_two@entries <- taper_two@entries * cocons::cov_rns_taper_optimized_range(
+    taper_two@entries <- taper_two@entries * cocons::cov_rns_taper(
       theta = adjusted_eff_values,
       locs = coco.object@locs,
       x_covariates = X_std$std.covs,
       colindices = taper_two@colindices,
       rowpointers = taper_two@rowpointers,
-      smooth_limits = coco.object@info$smooth_limits
+      smooth_limits = coco.object@info$smooth.limits
     )
     
     pred_locs <- spam::nearest.dist(x = as.matrix(newlocs), y = coco.object@locs, delta = coco.object@info$delta)
@@ -175,7 +210,7 @@ cocoPredict <- function(coco.object,
     rm(pred_locs)
     
     # C(preds, locs)
-    pred_taper@entries <- pred_taper@entries * cocons::cov_rns_taper_optimized_predict_range(
+    pred_taper@entries <- pred_taper@entries * cocons::cov_rns_taper_pred(
       theta = adjusted_eff_values,
       locs = coco.object@locs,
       locs_pred = as.matrix(newlocs),
@@ -183,10 +218,10 @@ cocoPredict <- function(coco.object,
       x_covariates_pred = X_pred_std$std.covs,
       colindices = pred_taper@colindices,
       rowpointers = pred_taper@rowpointers,
-      smooth_limits = coco.object@info$smooth_limits
+      smooth_limits = coco.object@info$smooth.limits
     )
     
-    inv_cov <- spam::solve(taper_two, spam::t(pred_taper)) # consumes a lot of memory... more efficient would be solve(taper_two, coco.object@z) and then multiply... but for CRPS we need what it's implemented
+    inv_cov <- spam::solve(taper_two, spam::t(pred_taper)) # memory intensive
     
     # trend
     trend_pred <- c(X_pred_std$std.covs %*% adjusted_eff_values$mean) # crossprod ?
