@@ -1,25 +1,51 @@
 
-#' Marginal and conditional simulation of Gaussian processes with nonstationary covariance function
-#' @description simulates a Gaussian process with nonstationary covariance function
-#' from an coco object.
+#' Marginal and conditional simulation of nonstationary Gaussian process
+#' @description draw realizations of nonstationary Gaussian processes with covariate-based covariance functions.
+#' @details \code{'cond'} sim.type requires specifying in \code{'cond.info'} a list with \code{'newdataset'} a data.frame containing covariates present in model.list at simulation locations, 
+#' and \code{'newlocs'} a matrix with locations related to the simulation locations, matching indexing of \code{'newdataset'}. 
+#' 
+#' \code{type = 'classic'} assumes a simpler parameterization for the covariance function, assuming log-parameterizations for \code{'std.dev'}, \code{'scale'}, and \code{'smooth'}.
 #' 
 #' @usage cocoSim(coco.object, pars, n, seed, standardize, 
 #' type = 'classic', sim.type = NULL, cond.info = NULL)
-#' @param coco.object a vector of length p, where p is the number of parameters for
-#' @param pars a vector of length p, where p is the number of parameters for
-#' each of the models
-#' @param n number of realizations to simulate
-#' @param seed a list detailing in which position of each aspect the elements
-#' of theta should be placed. Expected to be output of getDesignMatrix
-#' @param seed seed number. default set to NULL.
-#' @param standardize logical argument describing whether provided covariates
-#' should be standardize (TRUE) or not (FALSE). By default set to TRUE
-#' @param type whether parameters are related to a classical parameterization ('classic') or
-#' a difference parameterization 'diff' . Default set to 'classic'. For 'sparse' coco objects, only 'diff' is available.
-#' @param sim.type if set 'cond' then a conditional simulation takes place.
-#' @param cond.info a list containing information to perform a conditional simulation.
-#' @returns a matrix n x dim(data)\[1\]
+#' @param coco.object (\code{S4}) a \link{coco} object.
+#' @param pars (\code{numeric vector}) a vector of parameters values related to \code{model.list}.
+#' @param n (\code{integer}) number of realizations to simulate.
+#' @param seed (\code{integer or NULL}) seed number. default set to NULL.
+#' @param standardize (\code{TRUE/FALSE}) logical argument describing whether provided covariates 
+#' should be standardize (TRUE) or not (FALSE). By default set to TRUE.
+#' @param type (\code{character}) whether parameters are related to a classical parameterization ('classic') or
+#' a difference parameterization \code{'diff'}. Default set to \code{'classic'}. For \code{'sparse'} coco objects, only \code{'diff'} is available.
+#' @param sim.type (\code{character}) if set \code{'cond'} then a conditional simulation takes place.
+#' @param cond.info (\code{list}) a list containing added information to perform conditional simulation.
+#' @returns (\code{matrix}) a matrix n x dim(data)\[1\].
 #' @author Federico Blasi
+#' @seealso [coco()]
+#' @examples
+#' \dontrun{
+#' 
+#' model.list <- list('mean' = 0,
+#'                    'std.dev' = formula( ~ 1 + cov_x + cov_y),
+#'                    'scale' = formula( ~ 1 + cov_x + cov_y),
+#'                    'aniso' = 0,
+#'                    'tilt' = 0,
+#'                    'smooth' = 0.5,
+#'                    'nugget' = -Inf)
+#'                    
+#' coco_object <- coco(type = 'dense',
+#'                     data = holes[[1]][1:1000,],
+#'                     locs = as.matrix(holes[[1]][1:1000,1:2]),
+#'                     z = holes[[1]][1:1000,]$z,
+#'                     model.list = model.list)
+#'                     
+#' coco_sim <- cocoSim(coco.object = coco_object,
+#'             pars = c(0,0.25,0.25,  # pars related to std.dev
+#'             log(0.25),1,-1),       # pars related to scale
+#'             n = 1, 
+#'             standardize = TRUE) 
+#'
+#' fields::quilt.plot(coco_object@locs,coco_sim)             
+#' }
 #' 
 cocoSim <- function(coco.object, 
                      pars,
@@ -32,8 +58,7 @@ cocoSim <- function(coco.object,
   
   # add a check to test whether length of pars match model specification
   
-  if(!(coco.object@type %in% c("dense", "sparse"))){stop("")} # should not be necessary if using a 
-  # valid coco object
+  .cocons.check.type(coco.object@type)
   
   if(coco.object@type == "dense"){
     
@@ -56,19 +81,19 @@ cocoSim <- function(coco.object,
         covmat <- cocons::cov_rns(theta = to_pass[-1], 
                                  locs = coco.object@locs,
                                  x_covariates = std_coco,
-                                 smooth_limits = coco.object@info$smooth_limits)
+                                 smooth_limits = coco.object@info$smooth.limits)
         
         covmat_pred <- cocons::cov_rns_pred(theta = to_pass[-1], 
                                            locs = coco.object@locs,
                                            locs_pred = as.matrix(cond.info$newlocs),
                                            x_covariates = std_coco,
                                            x_covariates_pred = std_pred,
-                                           smooth_limits = coco.object@info$smooth_limits)
+                                           smooth_limits = coco.object@info$smooth.limits)
         
         covmat_unobs <- cocons::cov_rns(theta = to_pass[-1], 
                                        locs = as.matrix(cond.info$newdataset),
                                        x_covariates = std_pred,
-                                       smooth_limits = coco.object@info$smooth_limits)
+                                       smooth_limits = coco.object@info$smooth.limits)
         
         part_b <- covmat_pred %*% solve(covmat) %*% t(covmat_pred)
         
@@ -109,7 +134,7 @@ cocoSim <- function(coco.object,
         
         if(!is.formula(coco.object@model.list$smooth)){
           
-          theta_to_fit$smooth[1] <- log(coco.object@info$smooth_limits[1])
+          theta_to_fit$smooth[1] <- log(coco.object@info$smooth.limits[1])
           
         }
         
@@ -123,7 +148,7 @@ cocoSim <- function(coco.object,
         covmat <- cocons::cov_rns(theta = theta_to_fit[-1], 
                                  locs = coco.object@locs,
                                  x_covariates = std_coco$std.covs,
-                                 smooth_limits = coco.object@info$smooth_limits) 
+                                 smooth_limits = coco.object@info$smooth.limits) 
       }
       
       cholS <- base::chol(covmat)
@@ -162,12 +187,12 @@ cocoSim <- function(coco.object,
       theta = c(coco.object@info$delta, 1)
     )
     
-    ref_taper@entries <- ref_taper@entries * cov_rns_taper_optimized_range(theta = theta_to_fit[-1], 
+    ref_taper@entries <- ref_taper@entries * cov_rns_taper(theta = theta_to_fit[-1], 
                                                                            locs = coco.object@locs, 
                                                                            x_covariates =  std_coco$std.covs, 
                                                                            colindices = ref_taper@colindices, 
                                                                            rowpointers = ref_taper@rowpointers,
-                                                                           smooth_limits =  coco.object@info$smooth_limits)
+                                                                           smooth_limits =  coco.object@info$smooth.limits)
     cholS <- spam::chol(ref_taper)
     iord <- spam::ordering(cholS, inv = TRUE)
     cholS <- spam::as.spam(cholS)
